## [UNRELEASED] neptune-prophet 0.0.1

### Features
- Logging model metadata, serialized models, Prophet's plots, and additional diagnostic plots ([#3](https://github.com/neptune-ai/neptune-prophet/pull/3))
